.. image:: https://s.weblate.org/cdn/Logo-Darktext-borders.png
   :alt: Weblate
   :target: https://weblate.org/
   :height: 80px

**Weblate is a copylefted libre software web-based continuous localization system,
used by over 2500 libre projects and companies in more than 165 countries.**

Install it, or use the Hosted Weblate service at `weblate.org`_.

.. image:: https://img.shields.io/badge/website-weblate.org-blue.svg
    :alt: Website
    :target: https://weblate.org/

.. image:: https://hosted.weblate.org/widgets/weblate/-/svg-badge.svg
    :alt: Translation status
    :target: https://hosted.weblate.org/engage/weblate/

.. image:: https://bestpractices.coreinfrastructure.org/projects/552/badge
    :alt: CII Best Practices
    :target: https://bestpractices.coreinfrastructure.org/projects/552

.. image:: https://img.shields.io/pypi/v/weblate.svg
    :target: https://pypi.org/project/Weblate/

.. image:: https://readthedocs.org/projects/weblate/badge/
    :target: https://docs.weblate.org/

.. image:: https://img.shields.io/github/license/WeblateOrg/weblate.svg
    :alt: License
    :target: https://github.com/WeblateOrg/weblate/blob/main/COPYING

Support
-------

Weblate is a libre software with optional professional support and cloud
hosting offerings. Check out https://weblate.org/hosting/ for more information.

Documentation
-------------

To be found in the ``docs`` directory of the source code, or
viewed online on https://docs.weblate.org/

Installation
------------

Setup instructions:

https://docs.weblate.org/en/latest/admin/install.html

Bugs
----

Please report feature requests and problems to:

https://github.com/WeblateOrg/weblate/issues

License
-------

Copyright © 2012–2021 Michal Čihař michal@cihar.com

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see https://www.gnu.org/licenses/.

.. _weblate.org: https://weblate.org/
